#ifndef NT2_INCLUDE_FUNCTIONS_IS_PRIME_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_PRIME_HPP_INCLUDED

#include <nt2/combinatorial/include/functions/is_prime.hpp>

#endif
